@@ -1,14 +1,10 @@
 from django.conf import settings
-from django.core.exceptions import ImproperlyConfigured
 from django.core.urlresolvers import reverse
 from django.http import HttpResponse, HttpResponseRedirect
 from django.views.decorators.csrf import csrf_exempt
 from django.views.generic import TemplateView
 from django.views.generic.edit import FormView
 from django.utils.decorators import method_decorator
-from django.utils.importlib import import_module
-
-from django.contrib.auth.decorators import login_required
 
 from openid.consumer.discover import OPENID_IDP_2_0_TYPE
 from openid.extensions import sreg
@@ -18,25 +14,17 @@ from openid.yadis.constants import YADIS_CONTENT_TYPE
 
 from identeco.forms import TrustForm
 from identeco.models import Trust
+from identeco.utils import load_path_attr
+
+
+LOGIN_REQUIRED = getattr(settings, "IDENTECO_LOGIN_REQUIRED", "django.contrib.auth.decorators.login_required")
 
 
 class OpenIDView(object):
 
     def get_openid_store(self):
         store = getattr(settings, "IDENTECO_STORE", "identeco.store.DjangoORMStore")
-        module, attr = store.rsplit(".", 1)
-
-        try:
-            mod = import_module(module)
-        except ImportError as e:
-            raise ImproperlyConfigured('Error importing the Identeco store %s: "%s"' % (store, e))
-
-        try:
-            s = getattr(mod, attr)()
-        except AttributeError as e:
-            raise ImproperlyConfigured('Error import Identeco store %s: "%s"' % (store, e))
-
-        return s
+        return load_path_attr(store)
 
     def get_openid_endpoint(self):
         return self.request.build_absolute_uri(reverse("identeco_endpoint"))
@@ -47,24 +35,20 @@ class OpenIDView(object):
     def render_openid_response(self, openid_response):
         if not hasattr(self, "server"):
             self.server = self.get_openid_server()
-
         try:
             webresponse = self.server.encodeResponse(openid_response)
         except EncodingError as e:
             self.template_name = self.template_names["error"]
             return self.render_to_response({"error": e.response.encodeToKVForm()})
-
         response = HttpResponse(webresponse.body)
         response.status_code = webresponse.code
-
         for header, value in webresponse.headers.iteritems():
             response[header] = value
-
         return response
 
 
 class OpenIDUserData(object):
-    
+
     def add_sreg(self, request, response, user):
         sreg_req = sreg.SRegRequest.fromOpenIDRequest(request)
         sreg_data = {
@@ -81,47 +65,36 @@ class DecideTrust(OpenIDView, OpenIDUserData, FormView):
 
     def get_initial(self):
         initial = super(DecideTrust, self).get_initial()
-
         initial.update({
             "trust_root": self.request.session.get("openid_request").trust_root,
         })
-
         return initial
 
     def get_form_kwargs(self):
         kwargs = super(DecideTrust, self).get_form_kwargs()
-
         kwargs.update({
             "openid_request": self.request.session.get("openid_request"),
         })
-
         return kwargs
 
     def form_valid(self, form):
         if form.cleaned_data["always_trust"]:
             Trust.objects.get_or_create(
-                            user=self.request.user,
-                            trust_root=form.cleaned_data["trust_root"],
-                            defaults={"always_trust": form.cleaned_data["always_trust"]}
-                        )
-
-        #identity = self.request.build_absolute_uri(self.request.user.get_absolute_url())
+                user=self.request.user,
+                trust_root=form.cleaned_data["trust_root"],
+                defaults={"always_trust": form.cleaned_data["always_trust"]}
+            )
         identity = self.request.build_absolute_uri(reverse("identeco_identity", kwargs={"username": self.request.user.username}))
-
         openid_request = self.request.session.get("openid_request")
-
         if self.request.POST.get("allow"):
             openid_response = openid_request.answer(True, identity=identity)
             self.add_sreg(openid_request, openid_response, self.request.user)
         else:
             openid_response = openid_request.answer(False, identity=identity)
-
         return self.render_openid_response(openid_response)
 
     def get(self, request, *args, **kwargs):
-        #identity = self.request.build_absolute_uri(self.request.user.get_absolute_url())
         identity = self.request.build_absolute_uri(reverse("identeco_identity", kwargs={"username": self.request.user.username}))
-
         try:
             openid_request = self.request.session.get("openid_request")
             t = Trust.objects.get(user=self.request.user, trust_root=openid_request.trust_root)
@@ -133,7 +106,7 @@ class DecideTrust(OpenIDView, OpenIDUserData, FormView):
             pass
         return super(DecideTrust, self).get(request, *args, **kwargs)
 
-    @method_decorator(login_required)
+    @method_decorator(load_path_attr(LOGIN_REQUIRED))
     def dispatch(self, *args, **kwargs):
         return super(DecideTrust, self).dispatch(*args, **kwargs)
 
@@ -153,7 +126,6 @@ class Endpoint(OpenIDView, OpenIDUserData, TemplateView):
                 try:
                     t = Trust.objects.get(user=self.request.user, trust_root=self.openid_request.trust_root)
                     if t.always_trust:
-                        #identity = self.request.build_absolute_uri(self.request.user.get_absolute_url())
                         identity = self.request.build_absolute_uri(reverse("identeco_identity", kwargs={"username": self.request.user.username}))
                         openid_response = self.openid_request.answer(True, identity=identity)
                         self.add_sreg(self.openid_request, openid_response, self.request.user)
@@ -167,17 +139,14 @@ class Endpoint(OpenIDView, OpenIDUserData, TemplateView):
 
     def process_openid_request(self, data):
         self.server = self.get_openid_server()
-
         try:
             self.openid_request = self.server.decodeRequest(data)
         except ProtocolError as e:
             self.template_name = self.template_names["error"]
             return self.render_to_response({"error": str(e)})
-
         if self.openid_request is None:
             self.template_name = self.template_names["empty"]
             return self.render_to_response({})
-
         if self.openid_request.mode in ["checkid_immediate", "checkid_setup"]:
             return self.handle_checkid()
         else:
@@ -209,13 +178,11 @@ class XRDS(TemplateView):
 
     def get_context_data(self, **kwargs):
         ctx = super(XRDS, self).get_context_data(**kwargs)
-
         ctx.update({
             "type_uris": self.get_type_uris(),
             "endpoint_uris": self.get_endpoint_uris(),
             "local_id": None if not self.identity else self.request.build_absolute_uri(reverse("identeco_identity", kwargs={"username": self.kwargs["username"]})),
         })
-
         return ctx
 
     def get(self, request, *args, **kwargs):
@@ -228,9 +195,7 @@ class Identity(TemplateView):
 
     def get_context_data(self, **kwargs):
         ctx = super(Identity, self).get_context_data(**kwargs)
-
         ctx.update({
             "username": self.kwargs.get("username"),
         })
-
         return ctx
